
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.28.3',
    'branch_nick': 'release-1.28',
    'revision_id': 'fe116434af98bf70d037bdd393809cbea2a3a29b',
    'revno': 11537
}
